package com.ruoyi.system.service.guarantee;


import com.ruoyi.system.domain.guarantee.GuaranteeInfo;

import java.util.List;

/**
 * 反担保基础信息Service接口
 * 
 * @author boman
 * @date 2024-08-01
 */
public interface IGuaranteeInfoService 
{
    /**
     * 查询反担保基础信息
     * 
     * @param guaranteeInfoId 反担保基础信息主键
     * @return 反担保基础信息
     */
    public GuaranteeInfo selectGuaranteeInfoByGuaranteeInfoId(Long guaranteeInfoId);

    /**
     * 查询反担保基础信息列表
     * 
     * @param guaranteeInfo 反担保基础信息
     * @return 反担保基础信息集合
     */
    public List<GuaranteeInfo> selectGuaranteeInfoList(GuaranteeInfo guaranteeInfo);

    /**
     * 新增反担保基础信息
     * 
     * @param guaranteeInfo 反担保基础信息
     * @return 结果
     */
    public int insertGuaranteeInfo(GuaranteeInfo guaranteeInfo);

    /**
     * 修改反担保基础信息
     * 
     * @param guaranteeInfo 反担保基础信息
     * @return 结果
     */
    public int updateGuaranteeInfo(GuaranteeInfo guaranteeInfo);

    /**
     * 批量删除反担保基础信息
     * 
     * @param guaranteeInfoIds 需要删除的反担保基础信息主键集合
     * @return 结果
     */
    public int deleteGuaranteeInfoByGuaranteeInfoIds(Long[] guaranteeInfoIds);

    /**
     * 删除反担保基础信息信息
     * 
     * @param guaranteeInfoId 反担保基础信息主键
     * @return 结果
     */
    public int deleteGuaranteeInfoByGuaranteeInfoId(Long guaranteeInfoId);
}
